Method: Firebase::Admin::Messaging::AndroidNotification#image

Defined in:
lib/firebase/admin/messaging/android_notification.rb

#imageString?

Returns URL of an image to be displayed in the notification.

Returns:

  • (String, nil)

    URL of an image to be displayed in the notification.



33
34
35
# File 'lib/firebase/admin/messaging/android_notification.rb', line 33

def image
  @image
end